@@ -1,10 +1,10 @@
 from staticconf import config
-from staticconf.loader import *
-from staticconf.getters import *
-from staticconf.readers import *
+from staticconf.loader import *   # flake8: noqa
+from staticconf.getters import *  # flake8: noqa
+from staticconf.readers import *  # flake8: noqa
 
 
-version         = "0.6.0"
+version         = "0.7.0"
 
 view_help       = config.view_help
 reload          = config.reload
