@@ -1,7 +1,7 @@
 """
 Facilitate testing of code which uses staticconf.
 """
-from staticconf import config
+from staticconf import config, loader
 
 
 class MockConfiguration(object):
@@ -10,7 +10,7 @@ class MockConfiguration(object):
     def __init__(self, *args, **kwargs):
         name                = kwargs.pop('namespace', config.DEFAULT)
         self.namespace      = config.get_namespace(name)
-        self.config_data    = dict(*args, **kwargs)
+        self.config_data    = dict(loader.flatten_dict(dict(*args, **kwargs)))
         self.old_values     = None
 
     def setup(self):
@@ -30,4 +30,4 @@ class MockConfiguration(object):
         return self.setup()
 
     def __exit__(self, *args):
-        self.teardown()
\ No newline at end of file
+        self.teardown()
